==> meta_auth-0.1.12-py3-none-any.whl: meta_auth/codenames/auditor.py <==
from edc_auth.codenames import auditor

auditor += [
    "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_aesusar",
    "meta_ae.view_aetmg",
    "meta_ae.view_deathreport",
    "meta_ae.view_deathreporttmg",
    "meta_ae.view_deathreporttmgsecond",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_ae.view_historicalaesusar",
    "meta_ae.view_historicalaetmg",
    "meta_ae.view_historicaldeathreport",
    "meta_ae.view_historicaldeathreporttmg",
    "meta_ae.view_historicaldeathreporttmgsecond",
    "meta_lists.view_arvregimens",
    "meta_lists.view_baselinesymptoms",
    "meta_lists.view_diabetessymptoms",
    "meta_lists.view_offstudyreasons",
    "meta_lists.view_oiprophylaxis",
    "meta_lists.view_symptoms",
    "meta_lists.view_nonadherencereasons",
    "meta_prn.view_endofstudy",
    "meta_prn.view_historicalendofstudy",
    "meta_prn.view_historicallosstofollowup",
    "meta_prn.view_historicalonschedule",
    "meta_prn.view_historicalprotocoldeviationviolation",
    "meta_prn.view_historicalunblindingrequest",
    "meta_prn.view_historicalunblindingreview",
    "meta_prn.view_losstofollowup",
    "meta_prn.view_onschedule",
    "meta_prn.view_protocoldeviationviolation",
    "meta_prn.view_unblindingrequest",
    "meta_prn.view_unblindingrequestoruser",
    "meta_prn.view_unblindingreview",
    "meta_prn.view_unblindingrevieweruser",
    "meta_screening.view_historicalicpreferral",
    "meta_screening.view_historicalscreeningpartone",
    "meta_screening.view_historicalscreeningpartthree",
    "meta_screening.view_historicalscreeningparttwo",
    "meta_screening.view_icpreferral",
    "meta_screening.view_screeningpartone",
    "meta_screening.view_screeningpartthree",
    "meta_screening.view_screeningparttwo",
    "meta_screening.view_subjectscreening",
    "meta_screening.view_subjectrefusal",
    "meta_subject.view_bloodresultsfbc",
    "meta_subject.view_bloodresultsglu",
    "meta_subject.view_bloodresultshba1c",
    "meta_subject.view_bloodresultslft",
    "meta_subject.view_bloodresultsrft",
    "meta_subject.view_complications",
    "meta_subject.view_followup",
    "meta_subject.view_followupvitals",
    "meta_subject.view_healtheconomics",
    "meta_subject.view_historicalbloodresultsfbc",
    "meta_subject.view_historicalbloodresultsglu",
    "meta_subject.view_historicalbloodresultshba1c",
    "meta_subject.view_historicalbloodresultslft",
    "meta_subject.view_historicalbloodresultsrft",
    "meta_subject.view_historicalcomplications",
    "meta_subject.view_historicalfollowup",
    "meta_subject.view_historicalfollowupvitals",
    "meta_subject.view_historicalhealtheconomics",
    "meta_subject.view_historicalmalariarapidtest",
    "meta_subject.view_historicalmedicationadherence",
    "meta_subject.view_historicalpatienthistory",
    "meta_subject.view_historicalphysicalexam",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_historicalurinedipsticktest",
    "meta_subject.view_malariarapidtest",
    "meta_subject.view_medicationadherence",
    "meta_subject.view_patienthistory",
    "meta_subject.view_physicalexam",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
    "meta_subject.view_urinedipsticktest",
]
auditor.sort()

==> meta_auth-0.1.16-py3-none-any.whl: meta_auth/codenames/auditor.py <==
from edc_auth.codenames import auditor

auditor += [
    "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_aesusar",
    "meta_ae.view_aetmg",
    "meta_ae.view_deathreport",
    "meta_ae.view_deathreporttmg",
    "meta_ae.view_deathreporttmgsecond",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_ae.view_historicalaesusar",
    "meta_ae.view_historicalaetmg",
    "meta_ae.view_historicaldeathreport",
    "meta_ae.view_historicaldeathreporttmg",
    "meta_ae.view_historicaldeathreporttmgsecond",
    "meta_lists.view_arvregimens",
    "meta_lists.view_baselinesymptoms",
    "meta_lists.view_diabetessymptoms",
    "meta_lists.view_offstudyreasons",
    "meta_lists.view_oiprophylaxis",
    "meta_lists.view_symptoms",
    "meta_lists.view_nonadherencereasons",
    "meta_prn.view_endofstudy",
    "meta_prn.view_historicalendofstudy",
    "meta_prn.view_historicallosstofollowup",
    "meta_prn.view_historicalonschedule",
    "meta_prn.view_historicalprotocoldeviationviolation",
    "meta_prn.view_historicalunblindingrequest",
    "meta_prn.view_historicalunblindingreview",
    "meta_prn.view_losstofollowup",
    "meta_prn.view_onschedule",
    "meta_prn.view_protocoldeviationviolation",
    "meta_prn.view_unblindingrequest",
    "meta_prn.view_unblindingrequestoruser",
    "meta_prn.view_unblindingreview",
    "meta_prn.view_unblindingrevieweruser",
    "meta_screening.view_historicalicpreferral",
    "meta_screening.view_historicalscreeningpartone",
    "meta_screening.view_historicalscreeningpartthree",
    "meta_screening.view_historicalscreeningparttwo",
    "meta_screening.view_icpreferral",
    "meta_screening.view_screeningpartone",
    "meta_screening.view_screeningpartthree",
    "meta_screening.view_screeningparttwo",
    "meta_screening.view_subjectscreening",
    "meta_screening.view_subjectrefusal",
    "meta_subject.view_bloodresultsfbc",
    "meta_subject.view_bloodresultsglu",
    "meta_subject.view_bloodresultshba1c",
    "meta_subject.view_bloodresultslft",
    "meta_subject.view_bloodresultsrft",
    "meta_subject.view_complications",
    "meta_subject.view_followup",
    "meta_subject.view_followupvitals",
    "meta_subject.view_healtheconomics",
    "meta_subject.view_historicalbloodresultsfbc",
    "meta_subject.view_historicalbloodresultsglu",
    "meta_subject.view_historicalbloodresultshba1c",
    "meta_subject.view_historicalbloodresultslft",
    "meta_subject.view_historicalbloodresultsrft",
    "meta_subject.view_historicalcomplications",
    "meta_subject.view_historicalfollowup",
    "meta_subject.view_historicalfollowupvitals",
    "meta_subject.view_historicalhealtheconomics",
    "meta_subject.view_historicalmalariatest",
    "meta_subject.view_historicalmedicationadherence",
    "meta_subject.view_historicalpatienthistory",
    "meta_subject.view_historicalphysicalexam",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_historicalurinedipsticktest",
    "meta_subject.view_malariatest",
    "meta_subject.view_medicationadherence",
    "meta_subject.view_patienthistory",
    "meta_subject.view_physicalexam",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
    "meta_subject.view_urinedipsticktest",
]
auditor.sort()
